/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://kenai.com/hg/bluebill~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.factsheet.bbc.io;

import javax.annotation.Nonnull;
import java.util.List;
import it.tidalwave.util.As;
import it.tidalwave.util.Id;
import it.tidalwave.util.Key;
import it.tidalwave.bluebill.factsheet.Biblio;
import org.openrdf.model.Statement;
import static it.tidalwave.semantic.vocabulary.DublinCoreVocabulary.*;
import static it.tidalwave.semantic.vocabulary.FoafVocabulary.*;
import static it.tidalwave.semantic.vocabulary.RdfVocabulary.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class BiblioUnmarshaller extends StatementUnmarshallerSupport
  {
    @Nonnull
    public As unmarshal (final @Nonnull List<Statement> statements, final @Nonnull Context context)
      {
        final Id id = findId(statements, context);
        Biblio biblio = new Biblio(id);

        for (final Statement statement : statements)
          {
            final String predicate = statement.getPredicate().stringValue();

            if (predicate.startsWith(NS_DC_TERMS))
              {
                final Key<Object> key = new Key<Object>(predicate);
                biblio = biblio.with(key, deserialize(statement.getObject()));
              }
            else if (!predicate.equals(TYPE_RDF_TYPE.stringValue())
                     && !predicate.equals(ID_FOAF_PRIMARY_TOPIC.stringValue()))
              {
                System.err.println("BIBLIO Unused statement: " + statement);
              }
          }

        return biblio;
      }
  }
