/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://kenai.com/hg/bluebill~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.factsheet.bbc.io;

import it.tidalwave.bluebill.factsheet.bbc.vocabulary.BbcVocabulary;
import javax.annotation.Nonnull;
import java.util.List;
import org.openrdf.model.Statement;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.semantic.io.spi.StatementUnmarshaller;
import it.tidalwave.semantic.io.spi.StatementUnmarshallerFactory;
import static it.tidalwave.semantic.vocabulary.FoafVocabulary.*;
import static it.tidalwave.semantic.vocabulary.RdfVocabulary.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class WoUnmarshallerFactory implements StatementUnmarshallerFactory
  {
    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Nonnull
    public StatementUnmarshaller findStatementUnmarshallerFor (final @Nonnull List<Statement> statements)
      throws NotFoundException
      {
        for (final Statement statement : statements)
          {
            final String subject = statement.getSubject().stringValue();
            final String object = statement.getObject().stringValue();
            final String predicate = statement.getPredicate().stringValue();

            if (predicate.equals(TYPE_RDF_TYPE.stringValue()))
              {
                if (object.equals(BbcVocabulary.TYPE_WO_SPECIES.stringValue()))
                  {
                    return new FactSheetUnmarshaller();
                  }

                if (object.equals(BbcVocabulary.ID_PO_CLIP.stringValue()))
                  {
                    return new MovieUnmarshaller();
                  }

                if (object.equals(BbcVocabulary.ID_PO_EPISODE.stringValue()))
                  {
                    return new MovieUnmarshaller();
                  }

                if (object.equals(ID_FOAF_IMAGE.stringValue()))
                  {
                    return new StillImageUnmarshaller();
                  }
              }

            if (subject.startsWith("http://www.bbc.co.uk/nature/adaptations/"))
              {
                return new AdaptationUnmarshaller();
              }

            if (subject.startsWith("http://www.bbc.co.uk/nature/habitats/"))
              {
                return new HabitatUnmarshaller();
              }

            if (predicate.equals(ID_FOAF_PRIMARY_TOPIC.stringValue()))
              {
                return new BiblioUnmarshaller();
              }
          }

        throw new NotFoundException();
      }
  }
