/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://kenai.com/hg/bluebill~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.factsheet.bbc.vocabulary;

import it.tidalwave.bluebill.factsheet.Adaptation;
import it.tidalwave.bluebill.factsheet.Biblio;
import it.tidalwave.bluebill.factsheet.Habitat;
import it.tidalwave.mobile.media.Movie;
import it.tidalwave.mobile.media.StillImage;
import it.tidalwave.util.Id;
import it.tidalwave.semantic.Type;
import it.tidalwave.util.Key;
import java.util.Collection;
import static it.tidalwave.semantic.GenericEntity.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public final class BbcVocabulary
  {
    private BbcVocabulary()
      {    
      }
    
    public static final String NS_WO                = "http://purl.org/ontology/wo/";
    public static final String NS_PO                = "http://purl.org/ontology/po/";

    public static final Type TYPE_WO_SPECIES        = new Type(NS_WO + "Species");
    public static final Type TYPE_WO_ADAPTATION     = new Type(NS_WO + "adaptation");
    public static final Type TYPE_WO_LIVES_IN       = new Type(NS_WO + "livesIn");

    public static final Id ID_PO_SUBJECT            = new Id(NS_PO + "subject");
    public static final Id ID_PO_CLIP               = new Id(NS_PO + "Clip");
    public static final Id ID_PO_EPISODE            = new Id(NS_PO + "Episode");
    
    // FIXME: review the URNs below. Probably TYPE_WO_ADAPTATION and LIVES_IN are not good, since they perhaps
    // are relations and not types. Find something appropriate for the others.
    public static final Key<Adaptation> ADAPTATION  = new Key<Adaptation>(TYPE_WO_ADAPTATION);
    public static final Key<Biblio>     BIBLIO      = new Key<Biblio>("urn:biblio");
    public static final Key<StillImage> IMAGE       = new Key<StillImage>("urn:stillImage");
    public static final Key<Movie>      MOVIE       = new Key<Movie>("urn:movie");
    public static final Key<Habitat>    HABITAT     = new Key<Habitat>(TYPE_WO_LIVES_IN);
    
    
    public static final String BBC_URI = "http://www.bbc.co.uk";
    public static final String BBC_DISPLAY_NAME = "BBC";
    public static final String BBC_SYNDICATION_GUIDELINES = "http://www.bbc.co.uk/aboutthebbc/policies/syndication.shtml";
    public static final String BBC_CONTEXT = "http://www.bbc.co.uk/";
  }
